import com.keyoti.rapidSpell.desktop.*;
import com.keyoti.rapidSpell.event.*;

import javax.swing.*;
import javax.swing.text.JTextComponent;
import java.awt.event.*;
import java.awt.Dimension;
import java.awt.BorderLayout;
import java.io.File;

/** Demonstrates how to use RapidSpell to check more than one JTextComponent */
public class MultipleExample extends JFrame implements ActionListener, SpellCheckListener{
	JMenuBar menuBar;
	JMenu menu;
	JMenuItem checkSpellingMenuItem;
	JTextArea box1 = new JTextArea("Thank you for trying RapidSpell Desktop Java, this demo shows how to use RapidSpellGUI to check multiple text boxes, the code for this is located in MultipleExample.java. \n", 20, 60)
				,box2 = new JTextArea("Herre are somee misspelloings and tipogrphic erorrs.", 20, 60);

	RapidSpellGUI rapidGUI;




	/* Create an array of JTextComponents to check-----*/
	JTextComponent[] componentsToCheck = {box1, box2};
	int componentPointer = 0;
	/*-------------------------------------------------*/


	public MultipleExample() {
		super("Spell");

		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			System.out.println("Couldn't configure look and feel: "+e.toString());
		}

        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });

		getContentPane().setLayout(new BorderLayout());


		//build menu bar
		menuBar = new JMenuBar();
		setJMenuBar(menuBar);
		//Build the first menu.
		menu = new JMenu("Spelling");
		menu.setMnemonic(KeyEvent.VK_S);
		menu.getAccessibleContext().setAccessibleDescription("The only menu in this program that has menu items");
		menuBar.add(menu);

		//a group of JMenuItems
		checkSpellingMenuItem = new JMenuItem("Check Spelling...",
								 KeyEvent.VK_C);
		checkSpellingMenuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F7, ActionEvent.ALT_MASK));

		menu.add(checkSpellingMenuItem);

		checkSpellingMenuItem.addActionListener(this);


	
		box1.setLineWrap(true);
		box1.setWrapStyleWord(true);

		box2.setLineWrap(true);
		box2.setWrapStyleWord(true);


		JScrollPane scrollPane = new JScrollPane(box1);
		scrollPane.setPreferredSize(new Dimension(600, 205));
		getContentPane().add(scrollPane, BorderLayout.NORTH);

		JScrollPane scrollPane2 = new JScrollPane(box2);
		scrollPane2.setPreferredSize(new Dimension(600, 205));
		getContentPane().add(scrollPane2, BorderLayout.SOUTH);


		//Create dialog checker object
		rapidGUI = new RapidSpellGUI();
		rapidGUI.setLocation(300,300);


		pack();
        setVisible(true);

		/*	Disable finished message box and listen to finished events--*/
		rapidGUI.setShowFinishedMessageBox(false);
		rapidGUI.addSpellCheckListener(this);
		/*---------------------------------------------------------------*/


	}


	/*-------------------------------------------------*/
	/** Listen to Spell check events */
	public void spellCheckStarted(SpellCheckEvent e){
	}
	public void spellCheckFinished(SpellCheckEvent e){
		//begin checking all components in array
		checkNextComponent();
	}
	/*-------------------------------------------------*/




	/** Listen to GUI events and perform actions depending on the button sending the event. */
	public void actionPerformed(ActionEvent e) 
	{
		if(e.getSource() == checkSpellingMenuItem){
			/*  Start spell check when menu clicked -----------*/
			checkNextComponent();
			/*-------------------------------------------------*/
		}
	}



	/* Check next component in array-------------------*/
	void checkNextComponent(){
		//if this is the first component, or we haven't finished all components nor cancelled the check
		if((componentPointer < componentsToCheck.length && !rapidGUI.isCancelled()) || componentPointer==0){

			//if we have more components to check after this one, don't automatically dispose at end
			if (componentPointer < componentsToCheck.length -1) rapidGUI.disposeAtEnd = false;
			else rapidGUI.disposeAtEnd = true;

			//when this is finished checkNextComponent will be called by spellCheckFinished
			rapidGUI.check(componentsToCheck[componentPointer]);

			//increment pointer to next component for next round
			componentPointer++;
		} else {
			componentPointer = 0;
			//if the spell check wasn't cancelled, show a message to user
			if (!rapidGUI.isCancelled()) JOptionPane.showMessageDialog(this, "The spelling check is complete.", "Spelling", JOptionPane.INFORMATION_MESSAGE);
		}
	}
	/*-------------------------------------------------*/	

	


	public static void main(String[] args) {
		MultipleExample t = new MultipleExample();
	}
	



}
